<?php
/*
Plugin Name: WooCommerce Free Price Replacer
Description: Replaces the price display with "FREE" if the product price is 0, and provides a setting to customize the text for free products.
Version: 1.0
Author: EasyToolsWP.com
*/

// Prevent direct file access
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

// Function to replace the price with 'FREE' if the price is 0
add_filter( 'woocommerce_get_price_html', 'replace_free_price_label', 10, 2 );
function replace_free_price_label( $price, $product ) {
    if ( $product->get_price() == 0 ) {
        $custom_text = get_option( 'wc_free_price_text', 'FREE' ); // Get custom text from settings, default is 'FREE'
        return '<span class="amount">' . esc_html( $custom_text ) . '</span>';
    }
    return $price;
}

// Create a setting under WooCommerce -> Settings -> Products
add_action( 'woocommerce_settings_tabs_array', 'add_free_price_settings_tab', 50 );
function add_free_price_settings_tab( $settings_tabs ) {
    $settings_tabs['free_price_settings'] = __( 'Free Price Settings', 'woocommerce-free-replacer' );
    return $settings_tabs;
}

add_action( 'woocommerce_settings_free_price_settings', 'add_free_price_settings_page' );
function add_free_price_settings_page() {
    woocommerce_admin_fields( get_free_price_settings() );
}

add_action( 'woocommerce_update_options_free_price_settings', 'update_free_price_settings' );
function update_free_price_settings() {
    woocommerce_update_options( get_free_price_settings() );
}

function get_free_price_settings() {
    $settings = array(
        'section_title' => array(
            'name'     => __( 'Free Price Text Settings', 'woocommerce-free-replacer' ),
            'type'     => 'title',
            'desc'     => 'Set how free products should be displayed.',
            'id'       => 'wc_free_price_settings_title'
        ),
        'free_price_text' => array(
            'name'     => __( 'Free Price Text', 'woocommerce-free-replacer' ),
            'type'     => 'text',
            'desc'     => __( 'Text to be displayed when the product is free.', 'woocommerce-free-replacer' ),
            'id'       => 'wc_free_price_text',
            'default'  => 'FREE',
            'css'      => 'min-width:300px;',
        ),
        'section_end' => array(
            'type' => 'sectionend',
            'id' => 'wc_free_price_settings_end'
        )
    );

    return $settings;
}
?>
